@@ -97,10 +97,13 @@ class Action():
                 if "parse_mode" in item:
                     parse_mode = item["parse_mode"]
                 print("type: ", type(update))
-                print("update: ", update)
+                print("update: ", update) 
                 if type(update) == CallbackQuery:
                     update.from_user.send_message(item["text"].format(
-                        **{"echo": update.message.text, "name": context.user_data["name"]}), reply_markup=reply_markup, parse_mode=parse_mode)
+                        **{"name": context.user_data["name"]}), reply_markup=reply_markup, parse_mode=parse_mode)
+                elif update.callback_query:
+                    update.callback_query.from_user.send_message(item["text"].format(
+                        **{"name": context.user_data["name"]}), reply_markup=reply_markup, parse_mode=parse_mode)
                 elif update.poll_answer:
                     update.poll_answer.user.send_message(item["text"].format(
                         **{"name": context.user_data["name"]}), reply_markup=reply_markup, parse_mode=parse_mode)
